==> apache-camel-3.18.3-src.zip: apache-camel-3.18.3/dsl/camel-endpointdsl/src/test/java/org/apache/camel/builder/endpoint/LanguageEndpointStaticTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.endpoint;

import org.apache.camel.builder.RouteBuilder;
import org.junit.jupiter.api.Test;

import static org.apache.camel.builder.endpoint.StaticEndpointBuilders.direct;
import static org.apache.camel.builder.endpoint.StaticEndpointBuilders.language;
import static org.apache.camel.builder.endpoint.StaticEndpointBuilders.mock;

public class LanguageEndpointStaticTest extends BaseEndpointDslTest {

    @Test
    public void testLanguage() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("Hello World");

        template.sendBody("direct:start", "World");

        assertMockEndpointsSatisfied();
    }

    @Test
    public void testLanguageFluent() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("Hello World");

        context.createFluentProducerTemplate()
                .to(direct("start"))
                .withBody("World")
                .send();

        assertMockEndpointsSatisfied();
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from(direct("start"))
                        .to(language("simple").script("Hello ${body}"))
                        .to(mock("result"));
            }
        };
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/dsl/camel-endpointdsl/src/test/java/org/apache/camel/builder/endpoint/LanguageEndpointStaticTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.builder.endpoint;

import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

import static org.apache.camel.builder.endpoint.StaticEndpointBuilders.direct;
import static org.apache.camel.builder.endpoint.StaticEndpointBuilders.language;
import static org.apache.camel.builder.endpoint.StaticEndpointBuilders.mock;

public class LanguageEndpointStaticTest extends BaseEndpointDslTest {

    @Test
    public void testLanguage() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("Hello World");

        template.sendBody("direct:start", "World");

        MockEndpoint.assertIsSatisfied(context);
    }

    @Test
    public void testLanguageFluent() throws Exception {
        getMockEndpoint("mock:result").expectedBodiesReceived("Hello World");

        context.createFluentProducerTemplate()
                .to(direct("start"))
                .withBody("World")
                .send();

        MockEndpoint.assertIsSatisfied(context);
    }

    @Override
    protected RouteBuilder createRouteBuilder() throws Exception {
        return new RouteBuilder() {
            @Override
            public void configure() throws Exception {
                from(direct("start"))
                        .to(language("simple").script("Hello ${body}"))
                        .to(mock("result"));
            }
        };
    }
}
